#!/usr/bin/env python3
"""
This script converts an AutoEq file for use with GEQs (graphic equalizers).
It prints the simplified version to screen (std_out).

Usage: wavelet_conv.py filename.txt
To save to a file, use redirection: wavelet_conv.py filename.txt > newfile.txt

Version: 0.1 beta
Author: GWolfman

AutoEq (@jaakkopasanen): https://github.com/jaakkopasanen/AutoEq
GEQ info (@sweetchaos): https://www.audiosciencereview.com/forum/index.php?threads/list-of-amirs-headphone-geq-filters.20043/

===
MIT License

Copyright (c) 2021 GWolfman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

import re
import sys

# Constants
DEBUG = False  # Change to True to print extra text for debugging, else False
R_HEADER = re.compile(r'^Preamp: (?P<gain>[-]?\d+.\d) dB$')
R_BAND = re.compile(r'^Filter \d+: (?P<on>\w+) (?P<type>\w+) Fc (?P<freq>\d+) Hz Gain (?P<gain>[-]?\d+.\d+) dB Q (?P<q>\d+.\d+)$')

# Variables
out_text = []

# Check command line argument(s)
if len(sys.argv) != 2:
    print("ERORR! See usage (-h).")
    exit(1)
elif sys.argv[1] == '-h':
    print("wavelet_conv.py filename.txt")
    exit(0)

# Try opening and reading the input file
try:
    with open(sys.argv[1], 'r') as fin:
        in_text = fin.readlines()

    # Remove newline characters
    in_text = [line.strip() for line in in_text]

    # Print input if debugging
    if DEBUG:
        print('=INPUT=\n', '\n'.join(in_text))
except Exception as err:
    print("INPUT FILE ERROR: {ERR}".format(ERR=err))
    print("    Does the file exist and do you have read permissions?")
    exit(2)

# Process each line of input
for line in in_text:
    if DEBUG:
        print('line:', line)

    # Try matching line to known type(s)
    l1 = R_HEADER.search(line)
    l2 = R_BAND.search(line)

    # If matching preamp header
    if l1 and l1.groups():
        if DEBUG:
            print("match header: gain={G}".format(G=l1.group('gain')))

        # Add formatted text to output
        out_text.append("Preamp: {G}db".format(G=l1.group('gain')))

        # Skip to next line
        continue

    # If matching filter line
    elif l2 and l2.groups():
        if DEBUG:
            print("match filter: on={O} type={T} f={F} gain={G} Q={Q}".format(
                O=l2.group('on'), T=l2.group('type'), F=l2.group('freq'),
                G=l2.group('gain'), Q=l2.group('q')))

        # Add formatted text to output
        out_text.append("{F} {G}".format(F=l2.group('freq'), G=l2.group('gain')))

        # Skip to next line
        continue

if DEBUG:
    print('=out_text=\n', (out_text))

# Save output to file
print('\r\n'.join(out_text))

# Exit gracefully
exit(0)

# vim: set noai ts=4 sw=4 sts=4 expandtab syntax=python: